# kedrogen

A simple CLI command that generate a Kedro project from a cookiecutter template in the current directory.

## Installation

```console
pip install kedrogen
```
  
## Usage

```console
$ kedrogen [OPTIONS] TEMPLATE
```

**Arguments**:

* `TEMPLATE_PATH`: Path or Git URL of the Cookiecutter template.  [required]

**Options**:

* `--verbose`: Show detailed output.
* `-q, --quiet`: Suppress all non-error messages.
* `-v, --version`: Show the version and exit.
* `--install-completion`: Install completion for the current shell.
* `--show-completion`: Show completion for the current shell, to copy it or customize the installation.
* `--help`: Show this message and exit.


## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`kedrogen` was created by Shafayet Khan Shafee. It is licensed under the terms of the MIT license.
